@@ -9,7 +9,7 @@
 # @Description  :
 """
 'console_scripts': [
-    'app-run=iapp.app_run.run:run'
+    'app-run=appzoo.app_run:cli'
 ]
 """
 import os
